@@ -31,7 +31,7 @@ from tiddlywebplugins.prettyerror import PrettyHTTPExceptor
 import tiddlywebplugins.status
 
 
-__version__ = '0.9.44'
+__version__ = '0.9.45'
 
 
 def init(config):
@@ -111,13 +111,12 @@ def init(config):
     tiddlywebplugins.lazy.init(config)
     tiddlywebplugins.privateer.init(config)
 
-    # XXX This is required to work around issues with twp.instancer.
-    # Without this, instance information from tiddlywebwiki wins
-    # because each plugin does its own get_tiddler_locations.
-    # This only fixes 'twanager update', instance creation
-    # still does not have the right information, thus requiring a
-    # twanager update after instance creation. Presumably the
-    # instance script needs to do something similar.
+    # XXX: The following is required to work around issues with twp.instancer.
+    # Without this, config settings from tiddlywebwiki take precedence.
+    config['serializers']['text/x-tiddlywiki'] = space_config['serializers']['text/x-tiddlywiki']
+    # This only fixes 'twanager update', instance creation still does not have
+    # the right information, thus requiring a twanager update after instance
+    # creation. Presumably the instance script needs to do something similar.
     config['instance_tiddlers'] = get_tiddler_locations(store_contents,
             'tiddlywebplugins.tiddlyspace')
 
